@@ -183,64 +183,64 @@ egg_cell_renderer_text_class_init (EggCellRendererTextClass *class)
   g_object_class_install_property (object_class,
                                    PROP_TEXT,
                                    g_param_spec_string ("text",
-                                                        _("Text"),
-                                                        _("Text to render"),
+                                                        "Text",
+                                                        "Text to render",
                                                         NULL,
                                                         G_PARAM_READWRITE));
   
   g_object_class_install_property (object_class,
                                    PROP_MARKUP,
                                    g_param_spec_string ("markup",
-                                                        _("Markup"),
-                                                        _("Marked up text to render"),
+                                                        "Markup",
+                                                        "Marked up text to render",
                                                         NULL,
                                                         G_PARAM_WRITABLE));
 
   g_object_class_install_property (object_class,
 				   PROP_ATTRIBUTES,
 				   g_param_spec_boxed ("attributes",
-						       _("Attributes"),
-						       _("A list of style attributes to apply to the text of the renderer"),
+						       "Attributes",
+						       "A list of style attributes to apply to the text of the renderer",
 						       PANGO_TYPE_ATTR_LIST,
 						       G_PARAM_READWRITE));
 
   g_object_class_install_property (object_class,
 				   PROP_ELLIPSIZE,
 				   g_param_spec_boolean ("ellipsize",
-							 _("Ellipsize"),
-							 _("Whether to crop the text and display \"...\" when space is limited"),
+							 "Ellipsize",
+							 "Whether to crop the text and display \"...\" when space is limited",
 							 FALSE,
 							 G_PARAM_READWRITE));
   
   g_object_class_install_property (object_class,
                                    PROP_BACKGROUND,
                                    g_param_spec_string ("background",
-                                                        _("Background color name"),
-                                                        _("Background color as a string"),
+                                                        "Background color name",
+                                                        "Background color as a string",
                                                         NULL,
                                                         G_PARAM_WRITABLE));
 
   g_object_class_install_property (object_class,
                                    PROP_BACKGROUND_GDK,
                                    g_param_spec_boxed ("background_gdk",
-                                                       _("Background color"),
-                                                       _("Background color as a GdkColor"),
+                                                       "Background color",
+                                                       "Background color as a GdkColor",
                                                        GDK_TYPE_COLOR,
                                                        G_PARAM_READABLE | G_PARAM_WRITABLE));  
 
   g_object_class_install_property (object_class,
                                    PROP_FOREGROUND,
                                    g_param_spec_string ("foreground",
-                                                        _("Foreground color name"),
-                                                        _("Foreground color as a string"),
+                                                        "Foreground color name",
+                                                        "Foreground color as a string",
                                                         NULL,
                                                         G_PARAM_WRITABLE));
 
   g_object_class_install_property (object_class,
                                    PROP_FOREGROUND_GDK,
                                    g_param_spec_boxed ("foreground_gdk",
-                                                       _("Foreground color"),
-                                                       _("Foreground color as a GdkColor"),
+                                                       "Foreground color",
+                                                       "Foreground color as a GdkColor",
                                                        GDK_TYPE_COLOR,
                                                        G_PARAM_READABLE | G_PARAM_WRITABLE));
 
@@ -248,24 +248,24 @@ egg_cell_renderer_text_class_init (EggCellRendererTextClass *class)
   g_object_class_install_property (object_class,
                                    PROP_EDITABLE,
                                    g_param_spec_boolean ("editable",
-                                                         _("Editable"),
-                                                         _("Whether the text can be modified by the user"),
+                                                         "Editable",
+                                                         "Whether the text can be modified by the user",
                                                          FALSE,
                                                          G_PARAM_READABLE | G_PARAM_WRITABLE));
 
   g_object_class_install_property (object_class,
                                    PROP_FONT,
                                    g_param_spec_string ("font",
-                                                        _("Font"),
-                                                        _("Font description as a string"),
+                                                        "Font",
+                                                        "Font description as a string",
                                                         NULL,
                                                         G_PARAM_READABLE | G_PARAM_WRITABLE));
 
   g_object_class_install_property (object_class,
                                    PROP_FONT_DESC,
                                    g_param_spec_boxed ("font_desc",
-                                                       _("Font"),
-                                                       _("Font description as a PangoFontDescription struct"),
+                                                       "Font",
+                                                       "Font description as a PangoFontDescription struct",
                                                        PANGO_TYPE_FONT_DESCRIPTION,
                                                        G_PARAM_READABLE | G_PARAM_WRITABLE));
 
@@ -273,16 +273,16 @@ egg_cell_renderer_text_class_init (EggCellRendererTextClass *class)
   g_object_class_install_property (object_class,
                                    PROP_FAMILY,
                                    g_param_spec_string ("family",
-                                                        _("Font family"),
-                                                        _("Name of the font family, e.g. Sans, Helvetica, Times, Monospace"),
+                                                        "Font family",
+                                                        "Name of the font family, e.g. Sans, Helvetica, Times, Monospace",
                                                         NULL,
                                                         G_PARAM_READABLE | G_PARAM_WRITABLE));
 
   g_object_class_install_property (object_class,
                                    PROP_STYLE,
                                    g_param_spec_enum ("style",
-                                                      _("Font style"),
-                                                      _("Font style"),
+                                                      "Font style",
+                                                      "Font style",
                                                       PANGO_TYPE_STYLE,
                                                       PANGO_STYLE_NORMAL,
                                                       G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -290,8 +290,8 @@ egg_cell_renderer_text_class_init (EggCellRendererTextClass *class)
   g_object_class_install_property (object_class,
                                    PROP_VARIANT,
                                    g_param_spec_enum ("variant",
-                                                     _("Font variant"),
-                                                     _("Font variant"),
+						      "Font variant",
+						      "Font variant",
                                                       PANGO_TYPE_VARIANT,
                                                       PANGO_VARIANT_NORMAL,
                                                       G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -299,8 +299,8 @@ egg_cell_renderer_text_class_init (EggCellRendererTextClass *class)
   g_object_class_install_property (object_class,
                                    PROP_WEIGHT,
                                    g_param_spec_int ("weight",
-                                                     _("Font weight"),
-                                                     _("Font weight"),
+                                                     "Font weight",
+                                                     "Font weight",
                                                      0,
                                                      G_MAXINT,
                                                      PANGO_WEIGHT_NORMAL,
@@ -309,8 +309,8 @@ egg_cell_renderer_text_class_init (EggCellRendererTextClass *class)
    g_object_class_install_property (object_class,
                                    PROP_STRETCH,
                                    g_param_spec_enum ("stretch",
-                                                      _("Font stretch"),
-                                                      _("Font stretch"),
+                                                      "Font stretch",
+                                                      "Font stretch",
                                                       PANGO_TYPE_STRETCH,
                                                       PANGO_STRETCH_NORMAL,
                                                       G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -318,8 +318,8 @@ egg_cell_renderer_text_class_init (EggCellRendererTextClass *class)
   g_object_class_install_property (object_class,
                                    PROP_SIZE,
                                    g_param_spec_int ("size",
-                                                     _("Font size"),
-                                                     _("Font size"),
+                                                     "Font size",
+                                                     "Font size",
                                                      0,
                                                      G_MAXINT,
                                                      0,
@@ -328,8 +328,8 @@ egg_cell_renderer_text_class_init (EggCellRendererTextClass *class)
   g_object_class_install_property (object_class,
                                    PROP_SIZE_POINTS,
                                    g_param_spec_double ("size_points",
-                                                        _("Font points"),
-                                                        _("Font size in points"),
+                                                        "Font points",
+                                                        "Font size in points",
                                                         0.0,
                                                         G_MAXDOUBLE,
                                                         0.0,
@@ -338,8 +338,8 @@ egg_cell_renderer_text_class_init (EggCellRendererTextClass *class)
   g_object_class_install_property (object_class,
                                    PROP_SCALE,
                                    g_param_spec_double ("scale",
-                                                        _("Font scale"),
-                                                        _("Font scaling factor"),
+                                                        "Font scale",
+                                                        "Font scaling factor",
                                                         0.0,
                                                         G_MAXDOUBLE,
                                                         1.0,
@@ -348,8 +348,8 @@ egg_cell_renderer_text_class_init (EggCellRendererTextClass *class)
   g_object_class_install_property (object_class,
                                    PROP_RISE,
                                    g_param_spec_int ("rise",
-                                                     _("Rise"),
-                                                     _("Offset of text above the baseline (below the baseline if rise is negative)"),
+                                                     "Rise",
+                                                     "Offset of text above the baseline (below the baseline if rise is negative)",
                                                      -G_MAXINT,
                                                      G_MAXINT,
                                                      0,
@@ -359,16 +359,16 @@ egg_cell_renderer_text_class_init (EggCellRendererTextClass *class)
   g_object_class_install_property (object_class,
                                    PROP_STRIKETHROUGH,
                                    g_param_spec_boolean ("strikethrough",
-                                                         _("Strikethrough"),
-                                                         _("Whether to strike through the text"),
+                                                         "Strikethrough",
+                                                         "Whether to strike through the text",
                                                          FALSE,
                                                          G_PARAM_READABLE | G_PARAM_WRITABLE));
   
   g_object_class_install_property (object_class,
                                    PROP_UNDERLINE,
                                    g_param_spec_enum ("underline",
-                                                      _("Underline"),
-                                                      _("Style of underline for this text"),
+                                                      "Underline",
+                                                      "Style of underline for this text",
                                                       PANGO_TYPE_UNDERLINE,
                                                       PANGO_UNDERLINE_NONE,
                                                       G_PARAM_READABLE | G_PARAM_WRITABLE));
