@@ -436,11 +436,8 @@ panel_addto_make_applet_model (PanelAddtoDialog *dialog)
 	GtkTreeIter iter;
 	GSList *item = NULL;
 
-	if (panel_profile_list_is_writable (PANEL_GCONF_APPLETS)) {
+	if (panel_profile_id_lists_are_writable ()) {
 		dialog->applet_list = panel_addto_query_applets (dialog->applet_list);
-	}
-
-	if (panel_profile_list_is_writable (PANEL_GCONF_OBJECTS)) {
 		dialog->applet_list = panel_addto_append_internal_applets (dialog->applet_list);
 	}
 
@@ -841,13 +838,21 @@ panel_addto_selection_changed (GtkTreeSelection *selection,
 	PanelAddtoItemInfo *data;
 	char               *iid;
 
-	if (!gtk_tree_selection_get_selected (selection, &model, &iter))
+	if (!gtk_tree_selection_get_selected (selection, &model, &iter)) {
+		gtk_widget_set_sensitive (GTK_WIDGET (dialog->add_button),
+					  FALSE);
 		return;
+	}
 
 	gtk_tree_model_get (model, &iter, COLUMN_DATA, &data, -1);
 
-	if (!data)
+	if (!data) {
+		gtk_widget_set_sensitive (GTK_WIDGET (dialog->add_button),
+					  FALSE);
 		return;
+	}
+
+	gtk_widget_set_sensitive (GTK_WIDGET (dialog->add_button), TRUE);
 
 	if (data->type == PANEL_ADDTO_LAUNCHER_MENU) {
 		gtk_button_set_label (GTK_BUTTON (dialog->add_button),
@@ -863,7 +868,7 @@ panel_addto_selection_changed (GtkTreeSelection *selection,
 	}
 
 	/* only allow dragging applets if we can add applets */
-	if (panel_profile_list_is_writable (PANEL_GCONF_APPLETS)) {
+	if (panel_profile_id_lists_are_writable ()) {
 		switch (data->type) {
 		case PANEL_ADDTO_LAUNCHER:
 			panel_addto_setup_launcher_drag (GTK_TREE_VIEW (dialog->tree_view),
@@ -945,6 +950,7 @@ panel_addto_dialog_new (PanelWidget *panel_widget)
 	dialog->add_button = gtk_dialog_add_button (GTK_DIALOG (dialog->addto_dialog),
 						     GTK_STOCK_ADD,
 						     PANEL_ADDTO_RESPONSE_ADD);
+	gtk_widget_set_sensitive (GTK_WIDGET (dialog->add_button), FALSE);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog->addto_dialog),
 				      FALSE);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog->addto_dialog),
