@@ -1822,11 +1822,12 @@ panel_widget_applet_drag_start (PanelWidget *panel,
 	g_message("Starting drag [grabbed] on a %s at %p\n",
 		  g_type_name(G_TYPE_FROM_INSTANCE(applet)), applet);
 #endif
-	panel_toplevel_block_auto_hide (panel->toplevel);
 
 	if (!panel_widget_applet_drag_start_no_grab (panel, applet, drag_off))
 		return;
 
+	panel_toplevel_push_autohide_disabler (panel->toplevel);
+
 	gtk_grab_add (applet);
 	if (applet->window) {
 		GdkGrabStatus  status;
@@ -1859,7 +1860,7 @@ panel_widget_applet_drag_end (PanelWidget *panel)
 	gdk_pointer_ungrab (GDK_CURRENT_TIME);
 	gtk_grab_remove (panel->currently_dragged_applet->applet);
 	panel_widget_applet_drag_end_no_grab (panel);
-	panel_toplevel_unblock_auto_hide (panel->toplevel);
+	panel_toplevel_pop_autohide_disabler (panel->toplevel);
 	gdk_flush ();
 }
 
